@@ -17,11 +17,11 @@ LocalTest - Test data and functions for L<Data::Validate::Type>.
 
 =head1 VERSION
 
-Version 1.0.0
+Version 1.4.1
 
 =cut
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.4.1';
 
 
 =head1 SYNOPSIS
@@ -304,9 +304,10 @@ Guillaume Aubert, C<< <aubertg at cpan.org> >>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-data-validate-type at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Data-Validate-Type>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests through the web interface at
+L<https://github.com/guillaumeaubert/Data-Validate-Type/issues>.
+I will be notified, and then you'll automatically be notified of progress on
+your bug as I make changes.
 
 
 =head1 SUPPORT
@@ -320,9 +321,9 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
+=item * GitHub (report bugs there)
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Data-Validate-Type>
+L<https://github.com/guillaumeaubert/Data-Validate-Type/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -332,16 +333,16 @@ L<http://annocpan.org/dist/Data-Validate-Type>
 
 L<http://cpanratings.perl.org/d/Data-Validate-Type>
 
-=item * Search CPAN
+=item * MetaCPAN
 
-L<http://search.cpan.org/dist/Data-Validate-Type/>
+L<https://metacpan.org/release/Data-Validate-Type>
 
 =back
 
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2012 Guillaume Aubert.
+Copyright 2012-2013 Guillaume Aubert.
 
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 3 as published by the Free
